==> leonardo-0.4.0-rc1.tgz: leonardo-0.4.0-rc1/lib/providers/draft.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import re
import time

import templates.draft as template
from providers.page import HTMLPage, ForbiddenPage
from web_resource import PagePart


def draft_menu_part(request, resource, config):

    if request.logged_in():
        draft_href = config.draft_href 
        menu_part = template.draft_menu % locals()
    else:
        menu_part = ""

    return menu_part


# form field names
page_title_name = "page_title"
page_content_name = "page_content"



# requires 'blog' and 'put' modules

class DraftProvider:


    def __init__(self, resource_manager, lfs, config):

        self.resource_manager = resource_manager
        self.lfs              = lfs
        self.config           = config

        self.draft_prefix       = config.draft_prefix
        

    def get(self, resource_id, request, main_resource):

        if not resource_id.startswith(self.draft_prefix):
            return None

        if not request.logged_in():
            return ForbiddenPage(resource_id, self.resource_manager, request, self.config)

        draft_path = resource_id[len(self.draft_prefix):].strip("/")
        
        if draft_path == "": # top level
            page_part = DraftListPagePart(resource_id, self.resource_manager, request, self.lfs, self.config)
            return HTMLPage(resource_id, page_part, self.resource_manager, request, self.config)

        else: # individual draft page
            if main_resource != None:  # if not a top-level request,
                return None            # don't handle it here

            outer_page_part = DraftPagePart(resource_id, self.resource_manager, request, self.config)
            return HTMLPage(resource_id, outer_page_part, self.resource_manager, request, self.config)



class DraftListPagePart(PagePart):


    def __init__(self, resource_id, resource_manager, request, lfs, config):
        status = ""

        # @@@ how can this be avoided?
        page_title_name = globals()["page_title_name"]
        page_content_name = globals()["page_content_name"]
        
        form_content = template.draft_initial_form_content % locals()

        # @@@ posting should really be done as a separate method
        if request.method == "POST":
            page_title = request.fields.getvalue(page_title_name, "")
            page_content = request.fields.getvalue(page_content_name, "")
            
            if page_title:
                draft_resource_id = config.draft_prefix + "/" + re.sub(' ', '_', page_title.lower())
                
                page = resource_manager.get(draft_resource_id, request, self)

                if page.exists():
                    status = template.draft_existing_title % locals()
                    form_content = page_content
                else:
                    page.set_content(page_content)

                    status = template.draft_success % locals()
            else:
                status = template.draft_no_title % locals()
                form_content = page_content
        
        title = template.draft_title
        
        # get list of drafts
        
        drafts = lfs.get_children(config.draft_prefix)[1]
    
        if drafts:
            
            draft_items = ""
            for draft_title in drafts:
                draft_link = config.draft_href + "/" + draft_title
                draft_items += template.draft_item % locals()

            draft_list = template.draft_list % locals()
        else:
            draft_list = template.empty_draft_list % locals()

        action = config.draft_href
        
        content = template.draft_page % locals()

        self.title = title
        self.html = content



class DraftPagePart(PagePart):


    def __init__(self, resource_id, resource_manager, request, config):
        page_part = resource_manager.get(resource_id, request, self)
        title = page_part.get_title()
        content = page_part.get_html()
        page_content = page_part.get_content()

        draft_path = resource_id[len(config.draft_prefix):].strip("/")

        post_action = config.put_href
        resource_name = config.put_resource_field
        page_content_name = config.put_content_field
        resource_id_to_put = draft_path

        content = template.draft_post_to_wiki_form % locals() + content

        resource_id_to_put = config.blog_prefix + "/%04d/%02d/%02d/" % tuple(time.localtime()[:3]) + draft_path
        content = template.draft_post_to_blog_form % locals() + content

        self.title = title
        self.html = content

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/providers/draft.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import re
import time
import urllib

import templates.draft as template
from providers.page import HTMLPage, ForbiddenPage
from web_resource import PagePart


def draft_menu_part(request, resource, config):

    if request.logged_in():
        draft_href = config.draft_href 
        menu_part = template.draft_menu % locals()
    else:
        menu_part = ""

    return menu_part


# form field names
page_id_name = "page_id"
page_content_name = "page_content"
page_content_type_name = "page_content_type"


# requires 'blog' and 'put' modules

class DraftProvider:


    def __init__(self, resource_manager, lfs, config):

        self.resource_manager = resource_manager
        self.lfs              = lfs
        self.config           = config

        self.draft_prefix       = config.draft_prefix
        

    def get(self, resource_id, request, main_resource):

        if not resource_id.startswith(self.draft_prefix):
            return None

        if not request.logged_in():
            return ForbiddenPage(resource_id, self.resource_manager, request, self.config)

        draft_path = resource_id[len(self.draft_prefix):].strip("/")
        
        if draft_path == "": # top level
            page_part = DraftListPagePart(resource_id, self.resource_manager, request, self.lfs, self.config)
            return HTMLPage(resource_id, page_part, self.resource_manager, request, self.config)

        else: # individual draft page
            if main_resource != None:  # if not a top-level request,
                return None            # don't handle it here

            outer_page_part = DraftPagePart(resource_id, self.resource_manager, request, self.config)
            return HTMLPage(resource_id, outer_page_part, self.resource_manager, request, self.config)



class DraftListPagePart(PagePart):


    def __init__(self, resource_id, resource_manager, request, lfs, config):
        status = ""

        # @@@ how can this be avoided?
        page_content_name = globals()["page_content_name"]
        page_content_type_name = globals()["page_content_type_name"]
        
        form_content = template.draft_initial_form_content % locals()

        # @@@ posting should really be done as a separate method
        if request.method == "POST":
            page_content = request.fields.getvalue(page_content_name, "")
            page_content_type = request.fields.getvalue(page_content_type_name, "")
            
            # @@@ this is a second place where a change to wiki format would result in a code change
            import wiki
            page_id = wiki.extract_title(page_content)
            
            if page_id:
                draft_resource_id = config.draft_prefix + "/" + re.sub(' ', '_', page_id.lower())
                
                page = resource_manager.get(draft_resource_id, request, self)

                if page.exists():
                    status = template.draft_existing_title % locals()
                    form_content = page_content
                else:
                    page.set_content(page_content, page_content_type)

                    status = template.draft_success % locals()
            else:
                status = template.draft_no_title % locals()
                form_content = page_content
        
        title = template.draft_title
        
        # get list of drafts
        
        drafts = lfs.get_children(config.draft_prefix)[1]
    
        if drafts:
            
            draft_items = ""
            for draft_title in drafts:
                draft_link = config.draft_href + "/" + urllib.quote(draft_title)
                draft_items += template.draft_item % locals()

            draft_list = template.draft_list % locals()
        else:
            draft_list = template.empty_draft_list % locals()

        action = config.draft_href
        
        page_content_type = config.draft_type_default
        
        content = template.draft_page % locals()

        self.title = title
        self.html = content



class DraftPagePart(PagePart):


    def __init__(self, resource_id, resource_manager, request, config):
    
        PagePart.__init__(self, resource_id)
    
        page_part = resource_manager.get(resource_id, request, self)
        title = page_part.get_title()
        content = page_part.get_html()
        page_content = page_part.get_content()
        page_content_type = page_part.get_content_type()

        page_content = re.sub(r'&', '&amp;', page_content)
        page_content = re.sub(r'<', '&lt;', page_content)
        page_content = re.sub(r'>', '&gt;', page_content)
        page_content = re.sub(r'"', '&quot;', page_content)

        draft_path = resource_id[len(config.draft_prefix):].strip("/")

        post_action = config.put_href
        resource_name = config.put_resource_field
        page_content_name = config.put_content_field
        page_content_type_name = config.put_content_type_field

        resource_id_to_put = config.blog_prefix + "/%04d/%02d/%02d/" % tuple(time.localtime()[:3]) + draft_path
        content = template.draft_put_form % locals() + content

        self.title = title
        self.html = content
        
    
    def is_read_only(self):
        return False
